==> mate-applets-1.19.1.tar.xz: mate-applets-1.19.1/drivemount/drive-list.h <==
/* -*- mode: C; c-basic-offset: 4 -*-
 * Drive Mount Applet
 * Copyright (c) 2004 Canonical Ltd
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Author:
 *   James Henstridge <jamesh@canonical.com>
 */

#ifndef DRIVE_LIST_H
#define DRIVE_LIST_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define DRIVE_TYPE_LIST         (drive_list_get_type ())
#define DRIVE_LIST(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), DRIVE_TYPE_LIST, DriveList))
#define DRIVE_LIST_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), DRIVE_TYPE_LIST, DriveListClass))
#define DRIVE_IS_LIST(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), DRIVE_TYPE_LIST))
#define DRIVE_IS_LIST_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), DRIVE_TYPE_LIST))
#define DRIVE_LIST_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), DRIVE_TYPE_LIST, DriveListClass))

typedef struct _DriveList      DriveList;
typedef struct _DriveListClass DriveListClass;

struct _DriveList
{
    GtkGrid parent;

    GHashTable *volumes;
    GHashTable *mounts;
    GtkOrientation orientation;
    guint layout_tag;
    GtkReliefStyle relief;
    GtkWidget *dummy;
    gint count;

    int icon_size;
};

struct _DriveListClass
{
    GtkGridClass parent_class;
};

GType      drive_list_get_type (void);
GtkWidget *drive_list_new (void);
void       drive_list_set_orientation (DriveList *list,
				       GtkOrientation orientation);
void       drive_list_set_panel_size  (DriveList *list,
				       int panel_size);
void       drive_list_set_transparent (DriveList *self,
				       gboolean transparent);
GSettings *settings;

#endif /* DRIVE_LIST_H */

==> mate-applets_1.22.2.orig.tar.xz: mate-applets-1.22.2/drivemount/drive-list.h <==
/* -*- mode: C; c-basic-offset: 4 -*-
 * Drive Mount Applet
 * Copyright (c) 2004 Canonical Ltd
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Author:
 *   James Henstridge <jamesh@canonical.com>
 */

#ifndef DRIVE_LIST_H
#define DRIVE_LIST_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define DRIVE_TYPE_LIST         (drive_list_get_type ())
#define DRIVE_LIST(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), DRIVE_TYPE_LIST, DriveList))
#define DRIVE_LIST_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), DRIVE_TYPE_LIST, DriveListClass))
#define DRIVE_IS_LIST(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), DRIVE_TYPE_LIST))
#define DRIVE_IS_LIST_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), DRIVE_TYPE_LIST))
#define DRIVE_LIST_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), DRIVE_TYPE_LIST, DriveListClass))

typedef struct _DriveList      DriveList;
typedef struct _DriveListClass DriveListClass;

struct _DriveList
{
    GtkGrid parent;

    GHashTable *volumes;
    GHashTable *mounts;
    GtkOrientation orientation;
    guint layout_tag;
    GtkReliefStyle relief;
    GtkWidget *dummy;
    gint count;

    int icon_size;
};

struct _DriveListClass
{
    GtkGridClass parent_class;
};

GType      drive_list_get_type (void);
GtkWidget *drive_list_new (void);
void       drive_list_set_orientation (DriveList *list,
				       GtkOrientation orientation);
void       drive_list_set_panel_size  (DriveList *list,
				       int panel_size);
void       drive_list_set_transparent (DriveList *self,
				       gboolean transparent);
GSettings *settings;
void       drive_list_redraw (DriveList *self);
void       settings_color_changed (GSettings *settings, gchar *key, DriveList *drive_list);

#endif /* DRIVE_LIST_H */
